<template>
  <div class="row">
    <div class="col-sm-12">
      <p class="text-muted">{{ t('account.advertise.create.category.select_category') }}</p>
    </div>
    <div class="col-sm-12">
      <!-- فیلد جستجو -->
      <form-input
          v-model="searchQuery"
          :placeholder="t('account.advertise.create.category.search_placeholder')"
      />
    </div>
    <div class="col-sm-12">
      <template v-if="data.loaded">
        <accordion name="categories">
          <template
              v-for="(category, index) in filteredCategories"
              :key="index"
          >
            <category-form-item
                v-model="inputValue"
                :category="category"
                :index="index"
            />
          </template>
        </accordion>
      </template>
      <template v-else>
        <shimmer v-for="i in 15" :key="i" height="43" custom-class="my-2"/>
      </template>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import { useCategoryStore } from "~/stores/data/category";
import {computed, onMounted, reactive, watch} from "vue";

const {t} = useI18n()
const {$windowSize} = useNuxtApp();

const emit = defineEmits(['update:modelValue']);

const props = defineProps({
  modelValue: {
    type: Object,
    required: true,
  }
});

const width = ref(parseFloat($windowSize?.width.value));

const inputValue = ref(props.modelValue);
const categoryStore = useCategoryStore();

const data = reactive({
  loaded: false,
  categories: [],
});

const categories = computed(() => categoryStore.categories);

// متغیر جستجو
const searchQuery = ref("");

// دسته‌بندی‌های فیلتر شده
const filteredCategories = computed(() => {
  if (!searchQuery.value.trim()) {
    return categories.value; // اگر جستجو خالی باشد، همه موارد نمایش داده می‌شوند
  }

  const search = searchQuery.value.trim().toLowerCase();

  // تابع بازگشتی برای فیلتر کردن دسته‌ها
  const filterCategories = (categories) => {
    return categories
        .map(category => {
          // بررسی تطابق نام دسته‌بندی
          const matches = category.title.toLowerCase().includes(search);

          // بررسی تطابق در زیرشاخه‌ها
          const filteredChildren = category.children
              ? filterCategories(category.children)
              : [];

          // اگر این دسته یا یکی از زیرشاخه‌های آن تطابق داشت، آن را نگه می‌داریم
          if (matches || filteredChildren.length > 0) {
            return {
              ...category,
              children: filteredChildren, // فقط زیرشاخه‌های فیلتر شده را نگه می‌داریم
            };
          }

          return null; // دسته‌ای که تطابق ندارد
        })
        .filter(Boolean); // حذف موارد null
  };

  return filterCategories(categories.value);
});

const {$api} = useNuxtApp();


watch(inputValue, (newValue) => {
  emit('update:modelValue', newValue);
});

onMounted(() => {
  data.loaded = false;

  setTimeout(() => {
    data.loaded = true;
  },300)
});
</script>